You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@tapestry.apache.org by hl...@apache.org on 2008/05/20 20:52:29 UTC

svn commit: r658390 [2/32] - in /tapestry/tapestry5/branches/hlship-20080520: ./ quickstart/src/main/resources/META-INF/ quickstart/src/main/resources/archetype-resources/src/main/java/pages/ quickstart/src/main/resources/archetype-resources/src/main/j...

Modified: tapestry/tapestry5/branches/hlship-20080520/build.xml
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/build.xml?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/build.xml (original)
+++ tapestry/tapestry5/branches/hlship-20080520/build.xml Tue May 20 11:51:35 2008
@@ -207,4 +207,4 @@
         <antcall target="assemble"/>
     </target>
 
-</project>
\ No newline at end of file
+</project>

Modified: tapestry/tapestry5/branches/hlship-20080520/pom.xml
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/pom.xml?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/pom.xml (original)
+++ tapestry/tapestry5/branches/hlship-20080520/pom.xml Tue May 20 11:51:35 2008
@@ -91,19 +91,19 @@
             <name>Tapestry User List</name>
             <subscribe>users-subscribe@tapestry.apache.org</subscribe>
             <unsubscribe>users-unsubscribe@tapestry.apache.org</unsubscribe>
-            <archive>http://markmail.org/search/list:org.apache.tapestry.users</archive>
+            <archive>http://markmail.org/search/list:org.apache.tapestry5.users</archive>
         </mailingList>
         <mailingList>
             <name>Tapestry Developer List</name>
             <subscribe>dev-subscribe@tapestry.apache.org</subscribe>
             <unsubscribe>dev-unsubscribe@tapestry.apache.org</unsubscribe>
-            <archive>http://markmail.org/search/list:org.apache.tapestry.dev</archive>
+            <archive>http://markmail.org/search/list:org.apache.tapestry5.dev</archive>
         </mailingList>
         <mailingList>
             <name>Tapestry Commits List</name>
             <subscribe>commits-subscribe@tapestry.apache.org</subscribe>
             <unsubscribe>commits-unsubscribe@tapestry.apache.org</unsubscribe>
-            <archive>http://markmail.org/search/list:org.apache.tapestry.commits</archive>
+            <archive>http://markmail.org/search/list:org.apache.tapestry5.commits</archive>
         </mailingList>
     </mailingLists>
 

Modified: tapestry/tapestry5/branches/hlship-20080520/quickstart/src/main/resources/META-INF/archetype.xml
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/quickstart/src/main/resources/META-INF/archetype.xml?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/quickstart/src/main/resources/META-INF/archetype.xml (original)
+++ tapestry/tapestry5/branches/hlship-20080520/quickstart/src/main/resources/META-INF/archetype.xml Tue May 20 11:51:35 2008
@@ -30,4 +30,4 @@
         <source>src/main/java/pages/Index.java</source>
         <source>src/main/java/services/AppModule.java</source>
     </sources>
-</archetype>
\ No newline at end of file
+</archetype>

Modified: tapestry/tapestry5/branches/hlship-20080520/quickstart/src/main/resources/archetype-resources/src/main/java/pages/Index.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/quickstart/src/main/resources/archetype-resources/src/main/java/pages/Index.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/quickstart/src/main/resources/archetype-resources/src/main/java/pages/Index.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/quickstart/src/main/resources/archetype-resources/src/main/java/pages/Index.java Tue May 20 11:51:35 2008
@@ -11,4 +11,4 @@
 	{ 
 		return new Date(); 
 	}
-}
\ No newline at end of file
+}

Modified: tapestry/tapestry5/branches/hlship-20080520/quickstart/src/main/resources/archetype-resources/src/main/java/services/AppModule.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/quickstart/src/main/resources/archetype-resources/src/main/java/services/AppModule.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/quickstart/src/main/resources/archetype-resources/src/main/java/services/AppModule.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/quickstart/src/main/resources/archetype-resources/src/main/java/services/AppModule.java Tue May 20 11:51:35 2008
@@ -2,15 +2,15 @@
 
 import java.io.IOException;
 
-import org.apache.tapestry.*;
-import org.apache.tapestry.ioc.MappedConfiguration;
-import org.apache.tapestry.ioc.OrderedConfiguration;
-import org.apache.tapestry.ioc.ServiceBinder;
-import org.apache.tapestry.ioc.annotations.InjectService;
-import org.apache.tapestry.services.Request;
-import org.apache.tapestry.services.RequestFilter;
-import org.apache.tapestry.services.RequestHandler;
-import org.apache.tapestry.services.Response;
+import org.apache.tapestry5.*;
+import org.apache.tapestry5.ioc.MappedConfiguration;
+import org.apache.tapestry5.ioc.OrderedConfiguration;
+import org.apache.tapestry5.ioc.ServiceBinder;
+import org.apache.tapestry5.ioc.annotations.InjectService;
+import org.apache.tapestry5.services.Request;
+import org.apache.tapestry5.services.RequestFilter;
+import org.apache.tapestry5.services.RequestHandler;
+import org.apache.tapestry5.services.Response;
 import org.slf4j.Logger;
 
 /**

Modified: tapestry/tapestry5/branches/hlship-20080520/quickstart/src/main/resources/archetype-resources/src/main/resources/log4j.properties
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/quickstart/src/main/resources/archetype-resources/src/main/resources/log4j.properties?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/quickstart/src/main/resources/archetype-resources/src/main/resources/log4j.properties (original)
+++ tapestry/tapestry5/branches/hlship-20080520/quickstart/src/main/resources/archetype-resources/src/main/resources/log4j.properties Tue May 20 11:51:35 2008
@@ -13,11 +13,11 @@
 log4j.category.${packageName}.services.AppModule.TimingFilter=info
 
 # Outputs a list of pages, components and mixins at startup.
-log4j.category.org.apache.tapestry.services.TapestryModule.ComponentClassResolver=info
+log4j.category.org.apache.tapestry5.services.TapestryModule.ComponentClassResolver=info
 
 # Outputs startup statistics; time to setup and initialize the registry, and a list of
 # available services.
-log4j.category.org.apache.tapestry.TapestryFilter=info
+log4j.category.org.apache.tapestry5.TapestryFilter=info
 
 
 # Turning on debug mode for a page or component will show all of the code changes that occur when the
@@ -25,4 +25,4 @@
 # the contruction of the page, including the runtime code modifications that occur. Verbose
 # mode is rarely used, as it outputs voluminous details about the rendering of the page.
 
-# log4j.category.${packageName}.pages.Index=debug
\ No newline at end of file
+# log4j.category.${packageName}.pages.Index=debug

Modified: tapestry/tapestry5/branches/hlship-20080520/quickstart/src/main/resources/archetype-resources/src/main/webapp/WEB-INF/web.xml
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/quickstart/src/main/resources/archetype-resources/src/main/webapp/WEB-INF/web.xml?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/quickstart/src/main/resources/archetype-resources/src/main/webapp/WEB-INF/web.xml (original)
+++ tapestry/tapestry5/branches/hlship-20080520/quickstart/src/main/resources/archetype-resources/src/main/webapp/WEB-INF/web.xml Tue May 20 11:51:35 2008
@@ -28,11 +28,11 @@
     </context-param>
     <filter>
         <filter-name>app</filter-name>
-        <filter-class>org.apache.tapestry.TapestryFilter</filter-class>
+        <filter-class>org.apache.tapestry5.TapestryFilter</filter-class>
     </filter>
     <filter-mapping>
         <filter-name>app</filter-name>
         <url-pattern>/*</url-pattern>
     </filter-mapping>
 </web-app>
-      
\ No newline at end of file
+      

Modified: tapestry/tapestry5/branches/hlship-20080520/src/site/apt/dev/bible.apt
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/src/site/apt/dev/bible.apt?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/src/site/apt/dev/bible.apt (original)
+++ tapestry/tapestry5/branches/hlship-20080520/src/site/apt/dev/bible.apt Tue May 20 11:51:35 2008
@@ -104,10 +104,10 @@
   to change it.  As soon as code is public, we become handcuffed to backwards compatibility.
 
   <<Interfaces are public, implementations are private>>.  You can see this is the bulk of the code, where
-  org.apache.tapestry.services is almost all interfaces and the implementations are
-  in org.apache.tapestry.internal.services.
+  org.apache.tapestry5.services is almost all interfaces and the implementations are
+  in org.apache.tapestry5.internal.services.
 
-  Many more services have both the interface and the implementation in org.apache.tapestry.internal.services.
+  Many more services have both the interface and the implementation in org.apache.tapestry5.internal.services.
 
   We absolutely <<do not>> want to make Page or ComponentPageElement public.  You will often see
   public service facades that take a page name as a method parameter,

Modified: tapestry/tapestry5/branches/hlship-20080520/src/site/apt/index.apt
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/src/site/apt/index.apt?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/src/site/apt/index.apt (original)
+++ tapestry/tapestry5/branches/hlship-20080520/src/site/apt/index.apt Tue May 20 11:51:35 2008
@@ -255,7 +255,7 @@
   
   With the clean slate of Tapestry 5, we are being much more ruthless about internal vs. external.
   
-  First of all, anything inside the org.apache.tapestry.internal package
+  First of all, anything inside the org.apache.tapestry5.internal package
   is <<internal>>.  It is part of the implementation of Tapestry.  It is the man behind the curtain.
   You should not ever need to directly use this code.  It is a <<bad idea>> to do so, because
   internal code may <<change from one release to the next>> without concern for backwards

Modified: tapestry/tapestry5/branches/hlship-20080520/src/site/xdoc/release-notes.xml
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/src/site/xdoc/release-notes.xml?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/src/site/xdoc/release-notes.xml (original)
+++ tapestry/tapestry5/branches/hlship-20080520/src/site/xdoc/release-notes.xml Tue May 20 11:51:35 2008
@@ -1100,7 +1100,7 @@
             </li>
             <li>
                 [<a href="https://issues.apache.org/jira/browse/TAPESTRY-1443">TAPESTRY-1443</a>] -
-                org.apache.tapestry.annotation.Service annotation is
+                org.apache.tapestry5.annotations.Service annotation is
                 ignored
             </li>
             <li>

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-annotations/src/main/java/org/apache/tapestry5/beaneditor/DataType.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-annotations/src/main/java/org/apache/tapestry5/beaneditor/DataType.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-annotations/src/main/java/org/apache/tapestry5/beaneditor/DataType.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-annotations/src/main/java/org/apache/tapestry5/beaneditor/DataType.java Tue May 20 11:51:35 2008
@@ -12,14 +12,14 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.beaneditor;
+package org.apache.tapestry5.beaneditor;
 
 import java.lang.annotation.*;
 
 /**
- * Used to explicitly set the data type used to select an editor (or display) block.  Normally, the data type
- * is determined from the type of the property (for example, property type java.lang.String would map to data
- * type "text").
+ * Used to explicitly set the data type used to select an editor (or display) block.  Normally, the data type is
+ * determined from the type of the property (for example, property type java.lang.String would map to data type
+ * "text").
  */
 @Target(ElementType.METHOD)
 @Retention(RetentionPolicy.RUNTIME)

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-annotations/src/main/java/org/apache/tapestry5/beaneditor/NonVisual.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-annotations/src/main/java/org/apache/tapestry5/beaneditor/NonVisual.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-annotations/src/main/java/org/apache/tapestry5/beaneditor/NonVisual.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-annotations/src/main/java/org/apache/tapestry5/beaneditor/NonVisual.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.beaneditor;
+package org.apache.tapestry5.beaneditor;
 
 import java.lang.annotation.Documented;
 import static java.lang.annotation.ElementType.METHOD;
@@ -21,13 +21,13 @@
 import java.lang.annotation.Target;
 
 /**
- * Marker annotation for properties which are non-visual, and so should not appear (by default)
- * inside a {@link BeanModel}. The annotation may be placed on either the getter or the setter
- * method.
+ * Marker annotation for properties which are non-visual, and so should not appear (by default) inside a {@link
+ * BeanModel}. The annotation may be placed on either the getter or the setter method.
  */
 @Target(METHOD)
 @Retention(RUNTIME)
 @Documented
-public @interface NonVisual {
+public @interface NonVisual
+{
 
 }

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-annotations/src/main/java/org/apache/tapestry5/beaneditor/OrderAfter.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-annotations/src/main/java/org/apache/tapestry5/beaneditor/OrderAfter.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-annotations/src/main/java/org/apache/tapestry5/beaneditor/OrderAfter.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-annotations/src/main/java/org/apache/tapestry5/beaneditor/OrderAfter.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.beaneditor;
+package org.apache.tapestry5.beaneditor;
 
 import java.lang.annotation.Documented;
 import static java.lang.annotation.ElementType.METHOD;
@@ -21,13 +21,14 @@
 import java.lang.annotation.Target;
 
 /**
- * Placed on either a property getter or a property setter method to control the order in which the
- * properties are presented to the user.
+ * Placed on either a property getter or a property setter method to control the order in which the properties are
+ * presented to the user.
  */
 @Target(METHOD)
 @Retention(RUNTIME)
 @Documented
-public @interface OrderAfter {
+public @interface OrderAfter
+{
     /**
      * The name of the other property. This property will be ordered before the other property.
      */

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-annotations/src/main/java/org/apache/tapestry5/beaneditor/OrderBefore.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-annotations/src/main/java/org/apache/tapestry5/beaneditor/OrderBefore.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-annotations/src/main/java/org/apache/tapestry5/beaneditor/OrderBefore.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-annotations/src/main/java/org/apache/tapestry5/beaneditor/OrderBefore.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.beaneditor;
+package org.apache.tapestry5.beaneditor;
 
 import java.lang.annotation.Documented;
 import static java.lang.annotation.ElementType.METHOD;
@@ -21,13 +21,14 @@
 import java.lang.annotation.Target;
 
 /**
- * Placed on either a property getter or a property setter method to control the order in which the
- * properties are presented to the user.
+ * Placed on either a property getter or a property setter method to control the order in which the properties are
+ * presented to the user.
  */
 @Target(METHOD)
 @Retention(RUNTIME)
 @Documented
-public @interface OrderBefore {
+public @interface OrderBefore
+{
     /**
      * The name of the other property. This property will be ordered before the other property.
      */

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-annotations/src/main/java/org/apache/tapestry5/beaneditor/RelativePosition.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-annotations/src/main/java/org/apache/tapestry5/beaneditor/RelativePosition.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-annotations/src/main/java/org/apache/tapestry5/beaneditor/RelativePosition.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-annotations/src/main/java/org/apache/tapestry5/beaneditor/RelativePosition.java Tue May 20 11:51:35 2008
@@ -12,12 +12,13 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.beaneditor;
+package org.apache.tapestry5.beaneditor;
 
 /**
  * Controls the position of newly added {@link PropertyModel}s inside a {@link BeanModel}.
  */
-public enum RelativePosition {
+public enum RelativePosition
+{
     /**
      * The new {@link PropertyModel} goes before the existing model.
      */

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-annotations/src/main/java/org/apache/tapestry5/beaneditor/Validate.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-annotations/src/main/java/org/apache/tapestry5/beaneditor/Validate.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-annotations/src/main/java/org/apache/tapestry5/beaneditor/Validate.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-annotations/src/main/java/org/apache/tapestry5/beaneditor/Validate.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.beaneditor;
+package org.apache.tapestry5.beaneditor;
 
 import java.lang.annotation.Documented;
 import static java.lang.annotation.ElementType.METHOD;
@@ -21,15 +21,15 @@
 import java.lang.annotation.Target;
 
 /**
- * Used to attach validation constraints directly to a property (either the getter or the setter
- * method). The annotation value is a comma separated list of <em>validation constraints</em>,
- * each one identifying a validator type (such as "required", "minlength") and optionally, a
- * constraint value. Most validators need a constraint value, which is separated from the type by an
- * equals size (i.e., "maxlength=30").
+ * Used to attach validation constraints directly to a property (either the getter or the setter method). The annotation
+ * value is a comma separated list of <em>validation constraints</em>, each one identifying a validator type (such as
+ * "required", "minlength") and optionally, a constraint value. Most validators need a constraint value, which is
+ * separated from the type by an equals size (i.e., "maxlength=30").
  */
 @Target(METHOD)
 @Retention(RUNTIME)
 @Documented
-public @interface Validate {
+public @interface Validate
+{
     String value();
 }

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-annotations/src/main/java/org/apache/tapestry5/beaneditor/Width.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-annotations/src/main/java/org/apache/tapestry5/beaneditor/Width.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-annotations/src/main/java/org/apache/tapestry5/beaneditor/Width.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-annotations/src/main/java/org/apache/tapestry5/beaneditor/Width.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.beaneditor;
+package org.apache.tapestry5.beaneditor;
 
 import java.lang.annotation.Documented;
 import static java.lang.annotation.ElementType.METHOD;
@@ -21,9 +21,9 @@
 import java.lang.annotation.Target;
 
 /**
- * Defines the desired width of the field used to edit the property.  Note that width (generally equivalent to the
- * size attribute of an HTML &lt;input&gt; element) is only used for presentation; validation must be used to
- * actually enforce a maximum input length.
+ * Defines the desired width of the field used to edit the property.  Note that width (generally equivalent to the size
+ * attribute of an HTML &lt;input&gt; element) is only used for presentation; validation must be used to actually
+ * enforce a maximum input length.
  */
 @Target(METHOD)
 @Retention(RetentionPolicy.RUNTIME)

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-annotations/src/main/java/org/apache/tapestry5/ioc/annotations/Inject.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-annotations/src/main/java/org/apache/tapestry5/ioc/annotations/Inject.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-annotations/src/main/java/org/apache/tapestry5/ioc/annotations/IntermediateType.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-annotations/src/main/java/org/apache/tapestry5/ioc/annotations/IntermediateType.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.annotation;
+package org.apache.tapestry5.ioc.annotations;
 
 import java.lang.annotation.*;
 
@@ -20,10 +20,10 @@
 /**
  * Used to guide Tapestry when coercing from a raw type to a field or parameter type, by forcing Tapestry to coerce to
  * the intermediate type.  This was introduced to allow coercion from string to a time period (in milliseconds) via
- * {@link org.apache.tapestry.ioc.util.TimeInterval}.
+ * {@link org.apache.tapestry5.ioc.util.TimeInterval}.
  *
- * @see org.apache.tapestry.ioc.annotation.Value
- * @see org.apache.tapestry.ioc.annotation.Symbol
+ * @see org.apache.tapestry5.ioc.annotations.Value
+ * @see org.apache.tapestry5.ioc.annotations.Symbol
  */
 @Target({ ElementType.PARAMETER, ElementType.FIELD })
 @Retention(RetentionPolicy.RUNTIME)

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-annotations/src/main/java/org/apache/tapestry5/ioc/annotations/Primary.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-annotations/src/main/java/org/apache/tapestry5/ioc/annotations/Primary.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-component-report/src/main/java/org/apache/tapestry/mojo/ClassDescription.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-component-report/src/main/java/org/apache/tapestry/mojo/ClassDescription.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.mojo;
+package org.apache.tapestry5.mojo;
 
-import static org.apache.tapestry.ioc.internal.util.CollectionFactory.newMap;
+import static org.apache.tapestry5.ioc.internal.util.CollectionFactory.newMap;
 
 import java.util.Map;
 

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-component-report/src/main/java/org/apache/tapestry/mojo/ComponentReport.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-component-report/src/main/java/org/apache/tapestry/mojo/ComponentReport.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-component-report/src/main/java/org/apache/tapestry/mojo/ComponentReport.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-component-report/src/main/java/org/apache/tapestry/mojo/ComponentReport.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.mojo;
+package org.apache.tapestry5.mojo;
 
 import nu.xom.*;
 import org.apache.commons.lang.StringUtils;
@@ -23,10 +23,10 @@
 import org.apache.maven.project.MavenProject;
 import org.apache.maven.reporting.AbstractMavenReport;
 import org.apache.maven.reporting.MavenReportException;
-import org.apache.tapestry.ioc.internal.util.CollectionFactory;
-import static org.apache.tapestry.ioc.internal.util.CollectionFactory.newList;
-import static org.apache.tapestry.ioc.internal.util.CollectionFactory.newMap;
-import org.apache.tapestry.ioc.internal.util.InternalUtils;
+import org.apache.tapestry5.ioc.internal.util.CollectionFactory;
+import static org.apache.tapestry5.ioc.internal.util.CollectionFactory.newList;
+import static org.apache.tapestry5.ioc.internal.util.CollectionFactory.newMap;
+import org.apache.tapestry5.ioc.internal.util.InternalUtils;
 import org.codehaus.doxia.sink.Sink;
 import org.codehaus.doxia.site.renderer.SiteRenderer;
 import org.codehaus.plexus.util.cli.CommandLineException;
@@ -51,8 +51,8 @@
      */
     private static final String REFERENCE_DIR = "ref";
 
-    private final static String[] PARAMETER_HEADERS = {"Name", "Type", "Flags", "Default", "Default Prefix",
-            "Description"};
+    private final static String[] PARAMETER_HEADERS = { "Name", "Type", "Flags", "Default", "Default Prefix",
+            "Description" };
 
 
     /**
@@ -526,7 +526,7 @@
 
         String parametersPath = workDirectory + File.separator + "component-parameters.xml";
 
-        String[] arguments = {"-private", "-o", parametersPath,
+        String[] arguments = { "-private", "-o", parametersPath,
 
                 "-subpackages", rootPackage,
 
@@ -536,7 +536,7 @@
 
                 "-sourcepath", sourcePath(),
 
-                "-classpath", classPath()};
+                "-classpath", classPath() };
 
         command.addArguments(arguments);
 

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-component-report/src/main/java/org/apache/tapestry/mojo/ParameterDescription.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-component-report/src/main/java/org/apache/tapestry/mojo/ParameterDescription.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-component-report/src/main/java/org/apache/tapestry/mojo/ParameterDescription.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-component-report/src/main/java/org/apache/tapestry/mojo/ParameterDescription.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.mojo;
+package org.apache.tapestry5.mojo;
 
 public class ParameterDescription
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-component-report/src/main/java/org/apache/tapestry/mojo/ParametersDoclet.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-component-report/src/main/java/org/apache/tapestry/mojo/ParametersDoclet.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-component-report/src/main/java/org/apache/tapestry/mojo/ParametersDoclet.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-component-report/src/main/java/org/apache/tapestry/mojo/ParametersDoclet.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.mojo;
+package org.apache.tapestry5.mojo;
 
 import com.sun.javadoc.*;
 import com.sun.javadoc.AnnotationDesc.ElementValuePair;
@@ -124,7 +124,8 @@
         {
             for (AnnotationDesc annotation : fd.annotations())
             {
-                if (annotation.annotationType().qualifiedTypeName().equals("org.apache.tapestry.annotation.Parameter"))
+                if (annotation.annotationType().qualifiedTypeName().equals(
+                        "org.apache.tapestry5.annotations.Parameter"))
                 {
                     Map<String, String> result = new HashMap<String, String>();
 

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/pom.xml
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/pom.xml?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/pom.xml (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/pom.xml Tue May 20 11:51:35 2008
@@ -98,7 +98,7 @@
                 <artifactId>tapestry-component-report</artifactId>
                 <version>${project.version}</version>
                 <configuration>
-                    <rootPackage>org.apache.tapestry.corelib</rootPackage>
+                    <rootPackage>org.apache.tapestry5.corelib</rootPackage>
                     <apidocs>../apidocs</apidocs>
                 </configuration>
             </plugin>

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/AbstractOptionModel.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/AbstractOptionModel.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/Asset.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/Asset.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry;
+package org.apache.tapestry5;
 
-import org.apache.tapestry.ioc.Resource;
+import org.apache.tapestry5.ioc.Resource;
 
 /**
  * An Asset is any kind of resource that can be exposed to the client web browser. Although quite often an Asset is a

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/BaseValidationDecorator.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/BaseValidationDecorator.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/BaseValidationDecorator.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/BaseValidationDecorator.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry;
+package org.apache.tapestry5;
 
-import org.apache.tapestry.dom.Element;
+import org.apache.tapestry5.dom.Element;
 
 /**
  * Base implementation of {@link ValidationDecorator} that does nothing. Subclasses may override specific methods,

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/Binding.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/Binding.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/Binding.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/Binding.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry;
+package org.apache.tapestry5;
 
-import org.apache.tapestry.ioc.AnnotationProvider;
+import org.apache.tapestry5.ioc.AnnotationProvider;
 
 /**
  * A binding is a connection between a component and its container (another component), that allows the embedded

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/BindingConstants.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/BindingConstants.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/Block.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/Block.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry;
+package org.apache.tapestry5;
 
 /**
  * A block is a collection of static text and elements, and components, derived from a component template. In the

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/BlockNotFoundException.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/BlockNotFoundException.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/BlockNotFoundException.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/BlockNotFoundException.java Tue May 20 11:51:35 2008
@@ -12,10 +12,10 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry;
+package org.apache.tapestry5;
 
-import org.apache.tapestry.ioc.Locatable;
-import org.apache.tapestry.ioc.Location;
+import org.apache.tapestry5.ioc.Locatable;
+import org.apache.tapestry5.ioc.Location;
 
 /**
  * Exception thrown when a {@link Block} is requested but not found.

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/CSSClassConstants.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/CSSClassConstants.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/CSSClassConstants.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/CSSClassConstants.java Tue May 20 11:51:35 2008
@@ -1,4 +1,4 @@
-package org.apache.tapestry;
+package org.apache.tapestry5;
 
 /**
  * Constants used when rendering a CSS class attribute.

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/ClientElement.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/ClientElement.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/ClientElement.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/ClientElement.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry;
+package org.apache.tapestry5;
 
 
 /**

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/ComponentAction.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/ComponentAction.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/ComponentAction.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/ComponentAction.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry;
+package org.apache.tapestry5;
 
 import java.io.Serializable;
 

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/ComponentEventCallback.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/ComponentEventCallback.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/ContentType.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/ContentType.java Tue May 20 11:51:35 2008
@@ -12,11 +12,11 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry;
+package org.apache.tapestry5;
 
-import org.apache.tapestry.ioc.internal.util.CollectionFactory;
-import org.apache.tapestry.ioc.internal.util.Defense;
-import org.apache.tapestry.ioc.internal.util.InternalUtils;
+import org.apache.tapestry5.ioc.internal.util.CollectionFactory;
+import org.apache.tapestry5.ioc.internal.util.Defense;
+import org.apache.tapestry5.ioc.internal.util.InternalUtils;
 
 import java.util.List;
 import java.util.Map;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/EventConstants.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/EventConstants.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/EventConstants.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/EventConstants.java Tue May 20 11:51:35 2008
@@ -1,4 +1,4 @@
-package org.apache.tapestry;
+package org.apache.tapestry5;
 
 /**
  * Constant values for common event names fired by Tapestry components.

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/EventContext.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/EventContext.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/EventContext.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/EventContext.java Tue May 20 11:51:35 2008
@@ -12,14 +12,14 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry;
+package org.apache.tapestry5;
 
 /**
  * A collection of parameters that may eventually be passed to an event handler method.  Includes the ability to coerce
  * or encode parameters as needed.
  *
- * @see org.apache.tapestry.ioc.services.TypeCoercer
- * @see org.apache.tapestry.ValueEncoder
+ * @see org.apache.tapestry5.ioc.services.TypeCoercer
+ * @see org.apache.tapestry5.ValueEncoder
  */
 public interface EventContext
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/Field.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/Field.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/FormValidationControl.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/FormValidationControl.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry;
+package org.apache.tapestry5;
 
 /**
  * Allows control over validation concerns of a Form component.
@@ -46,4 +46,4 @@
      */
     public abstract void clearErrors();
 
-}
\ No newline at end of file
+}

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/Link.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/Link.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/Link.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/Link.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry;
+package org.apache.tapestry5;
 
 import org.apache.commons.codec.net.URLCodec;
 
@@ -21,7 +21,7 @@
 /**
  * A link is the Tapestry representation of a URL or URI that triggers dynamic behavior. This link is in three parts: a
  * path portion, an optional anchor, and a set of query parameters. A request for a link will ultimately be recognized
- * by a {@link org.apache.tapestry.services.Dispatcher}.
+ * by a {@link org.apache.tapestry5.services.Dispatcher}.
  * <p/>
  * Query parameter values are kept separate from the path portion to support encoding those values into hidden form
  * fields (where appropriate).

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/MarkupUtils.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/MarkupUtils.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/MarkupUtils.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/MarkupUtils.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry;
+package org.apache.tapestry5;
 
-import org.apache.tapestry.ioc.internal.util.CollectionFactory;
+import org.apache.tapestry5.ioc.internal.util.CollectionFactory;
 
 import java.util.Collections;
 import java.util.List;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/MarkupWriter.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/MarkupWriter.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/MarkupWriter.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/MarkupWriter.java Tue May 20 11:51:35 2008
@@ -12,12 +12,12 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry;
+package org.apache.tapestry5;
 
-import org.apache.tapestry.dom.Document;
-import org.apache.tapestry.dom.Element;
-import org.apache.tapestry.dom.MarkupModel;
-import org.apache.tapestry.dom.Raw;
+import org.apache.tapestry5.dom.Document;
+import org.apache.tapestry5.dom.Element;
+import org.apache.tapestry5.dom.MarkupModel;
+import org.apache.tapestry5.dom.Raw;
 
 import java.io.PrintWriter;
 

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/MarkupWriterAdapter.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/MarkupWriterAdapter.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/MarkupWriterListener.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/MarkupWriterListener.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry;
+package org.apache.tapestry5;
 
-import org.apache.tapestry.dom.Element;
+import org.apache.tapestry5.dom.Element;
 
 
 /**
@@ -26,8 +26,8 @@
      * Invoked just after an element and its initial set of attributes has been written.
      *
      * @param element element just created and populated with attributes
-     * @see org.apache.tapestry.MarkupWriter#element(String, Object[])
-     * @see org.apache.tapestry.MarkupWriter#elementNS(String, String)
+     * @see org.apache.tapestry5.MarkupWriter#element(String, Object[])
+     * @see org.apache.tapestry5.MarkupWriter#elementNS(String, String)
      */
     void elementDidStart(Element element);
 
@@ -35,7 +35,7 @@
      * Invoked just after an element has ended.
      *
      * @param element just ended
-     * @see org.apache.tapestry.MarkupWriter#end()
+     * @see org.apache.tapestry5.MarkupWriter#end()
      */
     void elementDidEnd(Element element);
 }

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/MetaDataConstants.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/MetaDataConstants.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/MetaDataConstants.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/MetaDataConstants.java Tue May 20 11:51:35 2008
@@ -1,9 +1,9 @@
-package org.apache.tapestry;
+package org.apache.tapestry5;
 
 /**
  * Meta-data keys that are applied to components and pages.
  *
- * @see org.apache.tapestry.services.MetaDataLocator
+ * @see org.apache.tapestry5.services.MetaDataLocator
  */
 public class MetaDataConstants
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/NullFieldStrategy.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/NullFieldStrategy.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/OptionGroupModel.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/OptionGroupModel.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry;
+package org.apache.tapestry5;
 
 import java.util.List;
 import java.util.Map;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/OptionModel.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/OptionModel.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/OptionModel.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/OptionModel.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry;
+package org.apache.tapestry5;
 
 import java.util.Map;
 

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/PersistenceConstants.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/PersistenceConstants.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/PersistenceConstants.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/PersistenceConstants.java Tue May 20 11:51:35 2008
@@ -1,9 +1,9 @@
-package org.apache.tapestry;
+package org.apache.tapestry5;
 
 /**
  * Constants for persistent field strategies.
  *
- * @see org.apache.tapestry.annotation.Persist#value()
+ * @see org.apache.tapestry5.annotations.Persist#value()
  */
 public class PersistenceConstants
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/PrimaryKeyEncoder.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/PrimaryKeyEncoder.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/PrimaryKeyEncoder.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/PrimaryKeyEncoder.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry;
+package org.apache.tapestry5;
 
-import org.apache.tapestry.corelib.components.Loop;
+import org.apache.tapestry5.corelib.components.Loop;
 
 import java.io.Serializable;
 import java.util.List;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/PropertyConduit.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/PropertyConduit.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/PropertyConduit.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/PropertyConduit.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry;
+package org.apache.tapestry5;
 
-import org.apache.tapestry.ioc.AnnotationProvider;
+import org.apache.tapestry5.ioc.AnnotationProvider;
 
 /**
  * Used to read or update the value associated with a property. A PropertyConduit provides access to the annotations on
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-annotations/src/main/java/org/apache/tapestry5/ioc/annotations/Inject.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-annotations/src/main/java/org/apache/tapestry5/ioc/annotations/Inject.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.annotation;
+package org.apache.tapestry5.ioc.annotations;
 
 import java.lang.annotation.Documented;
 import java.lang.annotation.ElementType;
@@ -31,8 +31,8 @@
  * <p/>
  * In terms of the IoC container; normally, resources take precedence over annotations when injecting. The Inject
  * annotation overrides this default, forcing the resolution of the parameters value via the master {@link
  * org.apache.tapestry.ioc.ObjectProvider}, even when the parameter's type matches a type that is normally a resource.
  * This is most often used in conjunction with {@link org.apache.tapestry.ioc.annotation.Value} annotation when
  * injecting a string, as normally, the String would be matched as the service id.
  * <p/>
  * In terms of the IoC container, the Inject annotation is only used on parameters to service builder methods (and
@@ -43,7 +43,7 @@
  * Finally, on a constructor, this is used to indicate <em>which</em> constructor should be used when more than one is
  * available.
  *
- * @see org.apache.tapestry.ioc.ObjectProvider
+ * @see org.apache.tapestry5.ioc.ObjectProvider
  */
 @Target(
         { PARAMETER, FIELD, ElementType.CONSTRUCTOR })
@@ -31,8 +31,8 @@
  * In terms of the IoC container; normally, resources take precedence over annotations when injecting. The Inject
  * annotation overrides this default, forcing the resolution of the parameters value via the master {@link
- * org.apache.tapestry.ioc.ObjectProvider}, even when the parameter's type matches a type that is normally a resource.
- * This is most often used in conjunction with {@link org.apache.tapestry.ioc.annotation.Value} annotation when
+ * org.apache.tapestry5.ioc.ObjectProvider}, even when the parameter's type matches a type that is normally a resource.
+ * This is most often used in conjunction with {@link org.apache.tapestry5.ioc.annotations.Value} annotation when
  * injecting a string, as normally, the String would be matched as the service id.
  * <p/>

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-annotations/src/main/java/org/apache/tapestry5/ioc/annotations/InjectService.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-annotations/src/main/java/org/apache/tapestry5/ioc/annotations/InjectService.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-annotations/src/main/java/org/apache/tapestry5/ioc/annotations/InjectService.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-annotations/src/main/java/org/apache/tapestry5/ioc/annotations/InjectService.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.annotation;
+package org.apache.tapestry5.ioc.annotations;
 
 import java.lang.annotation.Documented;
 import static java.lang.annotation.ElementType.PARAMETER;
@@ -26,7 +26,7 @@
 /**
  * Annotation used with parameters of service builder methods to identify the service to be injected
  * into the service builder method via the parameter. In many cases the
  * {@link org.apache.tapestry.ioc.annotation.Inject} annotation is more flexible or appropriate.
  *
  *
  */
@@ -26,7 +26,7 @@
  * Annotation used with parameters of service builder methods to identify the service to be injected
  * into the service builder method via the parameter. In many cases the
- * {@link org.apache.tapestry.ioc.annotation.Inject} annotation is more flexible or appropriate.
+ * {@link org.apache.tapestry5.ioc.annotations.Inject} annotation is more flexible or appropriate.
  *
  *

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-annotations/src/main/java/org/apache/tapestry5/ioc/annotations/IntermediateType.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-annotations/src/main/java/org/apache/tapestry5/ioc/annotations/IntermediateType.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-annotations/src/main/java/org/apache/tapestry5/ioc/annotations/Primary.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-annotations/src/main/java/org/apache/tapestry5/ioc/annotations/Primary.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.annotation;
+package org.apache.tapestry5.ioc.annotations;
 
 import java.lang.annotation.Documented;
 import static java.lang.annotation.ElementType.FIELD;
@@ -23,8 +23,8 @@
 
 /**
  * Marker annotation used to denote a service that is the primary instance of some common interface. This is often used
  * when a service is a {@linkplain org.apache.tapestry.ioc.services.ChainBuilder chain of command} or {@linkplain
  * org.apache.tapestry.ioc.services.StrategyBuilder strategy-based} and, therefore, many services will implement the
  * same interface.
  */
 @Target(
@@ -23,8 +23,8 @@
 /**
  * Marker annotation used to denote a service that is the primary instance of some common interface. This is often used
- * when a service is a {@linkplain org.apache.tapestry.ioc.services.ChainBuilder chain of command} or {@linkplain
- * org.apache.tapestry.ioc.services.StrategyBuilder strategy-based} and, therefore, many services will implement the
+ * when a service is a {@linkplain org.apache.tapestry5.ioc.services.ChainBuilder chain of command} or {@linkplain
+ * org.apache.tapestry5.ioc.services.StrategyBuilder strategy-based} and, therefore, many services will implement the
  * same interface.
  */

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-annotations/src/main/java/org/apache/tapestry5/ioc/annotations/Symbol.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-annotations/src/main/java/org/apache/tapestry5/ioc/annotations/Symbol.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-annotations/src/main/java/org/apache/tapestry5/ioc/annotations/Symbol.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-annotations/src/main/java/org/apache/tapestry5/ioc/annotations/Symbol.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.annotation;
+package org.apache.tapestry5.ioc.annotations;
 
 import java.lang.annotation.Documented;
 import static java.lang.annotation.ElementType.FIELD;
@@ -23,8 +23,8 @@
 
 /**
  * Used to inject a symbol value, via a symbol name. This is used much like {@link
  * org.apache.tapestry.ioc.annotation.Value} annotation, except that symbols are not expanded ... the entire value is a
  * symbol name. This allows the annotation to reference a public constant variable.
  */
 @Target(
         { PARAMETER, FIELD })
@@ -23,8 +23,8 @@
 /**
  * Used to inject a symbol value, via a symbol name. This is used much like {@link
- * org.apache.tapestry.ioc.annotation.Value} annotation, except that symbols are not expanded ... the entire value is a
- * symbol name. This allows the annotation to reference a public constant variable.
+ * org.apache.tapestry5.ioc.annotations.Value} annotation, except that symbols are not expanded ... the entire value is
+ * a symbol name. This allows the annotation to reference a public constant variable.
  */
 @Target(

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-annotations/src/main/java/org/apache/tapestry5/ioc/annotations/Value.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-annotations/src/main/java/org/apache/tapestry5/ioc/annotations/Value.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-annotations/src/main/java/org/apache/tapestry5/ioc/annotations/Value.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-annotations/src/main/java/org/apache/tapestry5/ioc/annotations/Value.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc.annotation;
+package org.apache.tapestry5.ioc.annotations;
 
 import java.lang.annotation.Documented;
 import static java.lang.annotation.ElementType.FIELD;
@@ -22,13 +22,13 @@
 import java.lang.annotation.Target;
 
 /**
  * Used in conjunction with {@link org.apache.tapestry.ioc.annotation.Inject} to inject a literal value, rather than a
  * service. Symbols in the value are expanded and the resulting string is coerced to the desired type. For IoC, this
  * annotation is only applied to parameters (on service builder methods, and on service constructors); for components,
  * it may also be applied to field.
  *
- * @see org.apache.tapestry.ioc.services.SymbolSource
- * @see org.apache.tapestry.ioc.services.TypeCoercer
+ * @see org.apache.tapestry5.ioc.services.SymbolSource
+ * @see org.apache.tapestry5.ioc.services.TypeCoercer
  */
 @Target(
         { PARAMETER, FIELD })
@@ -22,13 +22,13 @@
 
 /**
- * Used in conjunction with {@link org.apache.tapestry.ioc.annotation.Inject} to inject a literal value, rather than a
+ * Used in conjunction with {@link org.apache.tapestry5.ioc.annotations.Inject} to inject a literal value, rather than a
  * service. Symbols in the value are expanded and the resulting string is coerced to the desired type. For IoC, this
  * annotation is only applied to parameters (on service builder methods, and on service constructors); for components,

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-component-report/src/main/java/org/apache/tapestry/mojo/ClassDescription.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-component-report/src/main/java/org/apache/tapestry/mojo/ClassDescription.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/AbstractOptionModel.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/AbstractOptionModel.java Tue May 20 11:51:35 2008
@@ -12,13 +12,13 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry;
+package org.apache.tapestry5;
 
 import java.util.Map;
 
 /**
  * Base class for implementing {@link OptionModel}.  Subclasses must implement {@link
  * org.apache.tapestry.OptionModel#getLabel()} and {@link org.apache.tapestry.OptionModel#getValue()} }.
  */
 public abstract class AbstractOptionModel implements OptionModel
 {
@@ -12,13 +12,13 @@
 /**
  * Base class for implementing {@link OptionModel}.  Subclasses must implement {@link
- * org.apache.tapestry.OptionModel#getLabel()} and {@link org.apache.tapestry.OptionModel#getValue()} }.
+ * org.apache.tapestry5.OptionModel#getLabel()} and {@link org.apache.tapestry5.OptionModel#getValue()} }.
  */
 public abstract class AbstractOptionModel implements OptionModel

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/Asset.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/Asset.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/BindingConstants.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/BindingConstants.java Tue May 20 11:51:35 2008
@@ -1,8 +1,8 @@
-package org.apache.tapestry;
+package org.apache.tapestry5;
 
 /**
  * Constants for the built-in binding prefixes.  These are often used with the {@link
  * org.apache.tapestry.annotation.Parameter#defaultPrefix()} annotation attribute.
  */
 public class BindingConstants
 {
@@ -12,7 +12,7 @@
     public static final String LITERAL = "literal";
     /**
      * Binding expression prefix used to bind to a property of the component. When {@link
      * org.apache.tapestry.annotation.Parameter#defaultPrefix()} is not specified, the default is PROP.
      */
     public static final String PROP = "prop";
 
@@ -1,8 +1,8 @@
 /**
  * Constants for the built-in binding prefixes.  These are often used with the {@link
- * org.apache.tapestry.annotation.Parameter#defaultPrefix()} annotation attribute.
+ * org.apache.tapestry5.annotations.Parameter#defaultPrefix()} annotation attribute.
  */
 public class BindingConstants
@@ -12,7 +12,7 @@
     /**
      * Binding expression prefix used to bind to a property of the component. When {@link
-     * org.apache.tapestry.annotation.Parameter#defaultPrefix()} is not specified, the default is PROP.
+     * org.apache.tapestry5.annotations.Parameter#defaultPrefix()} is not specified, the default is PROP.
      */
     public static final String PROP = "prop";

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/Block.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/Block.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/ComponentEventCallback.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/ComponentEventCallback.java Tue May 20 11:51:35 2008
@@ -12,11 +12,11 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry;
+package org.apache.tapestry5;
 
 /**
  * Callback interface for a {@linkplain org.apache.tapestry.runtime.Event render phase event) or {@link
  * org.apache.tapestry.runtime.ComponentEvent}, notified when a non-null value is returned from some event handler
  * method.
  */
 public interface ComponentEventCallback<T>
@@ -28,7 +28,7 @@
      * <p/>
      * Boolean values are <em>not</em> passed to the handler.  Booleans are used to indicate that the event has been
      * handled (true) or that a further search for handlers should continue (true).  If a component event method returns
      * true, then {@link org.apache.tapestry.runtime.Event#isAborted()} will return true.
      *
      * @param result the result value return from the event handler method
      * @return true if the event is aborted, false if the event may continue
@@ -12,11 +12,11 @@
 
 /**
- * Callback interface for a {@linkplain org.apache.tapestry.runtime.Event render phase event) or {@link
- * org.apache.tapestry.runtime.ComponentEvent}, notified when a non-null value is returned from some event handler
+ * Callback interface for a {@linkplain org.apache.tapestry5.runtime.Event render phase event) or {@link
+ * org.apache.tapestry5.runtime.ComponentEvent}, notified when a non-null value is returned from some event handler
  * method.
  */
@@ -28,7 +28,7 @@
      * Boolean values are <em>not</em> passed to the handler.  Booleans are used to indicate that the event has been
      * handled (true) or that a further search for handlers should continue (true).  If a component event method returns
-     * true, then {@link org.apache.tapestry.runtime.Event#isAborted()} will return true.
+     * true, then {@link org.apache.tapestry5.runtime.Event#isAborted()} will return true.
      *
      * @param result the result value return from the event handler method

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/ComponentResources.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/ComponentResources.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/ComponentResources.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/ComponentResources.java Tue May 20 11:51:35 2008
@@ -12,14 +12,14 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry;
+package org.apache.tapestry5;
 
-import org.apache.tapestry.ioc.AnnotationProvider;
-import org.apache.tapestry.ioc.Messages;
-import org.apache.tapestry.ioc.Resource;
-import org.apache.tapestry.model.ComponentModel;
-import org.apache.tapestry.runtime.Component;
-import org.apache.tapestry.runtime.PageLifecycleListener;
+import org.apache.tapestry5.ioc.AnnotationProvider;
+import org.apache.tapestry5.ioc.Messages;
+import org.apache.tapestry5.ioc.Resource;
+import org.apache.tapestry5.model.ComponentModel;
+import org.apache.tapestry5.runtime.Component;
+import org.apache.tapestry5.runtime.PageLifecycleListener;
 
 import java.lang.annotation.Annotation;
 
@@ -188,7 +188,7 @@
 
     /**
      * Discards all persistent field changes for the page containing the component.  Changes are eliminated from
      * persistent storage (such as the {@link org.apache.tapestry.services.Session}) which will take effect in the
      * <em>next</em> request (the attached page instance is not affected).
      */
     void discardPersistentFieldChanges();
@@ -188,7 +188,7 @@
     /**
      * Discards all persistent field changes for the page containing the component.  Changes are eliminated from
-     * persistent storage (such as the {@link org.apache.tapestry.services.Session}) which will take effect in the
+     * persistent storage (such as the {@link org.apache.tapestry5.services.Session}) which will take effect in the
      * <em>next</em> request (the attached page instance is not affected).
      */

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/ComponentResourcesCommon.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/ComponentResourcesCommon.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/ComponentResourcesCommon.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/ComponentResourcesCommon.java Tue May 20 11:51:35 2008
@@ -12,16 +12,16 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry;
+package org.apache.tapestry5;
 
-import org.apache.tapestry.ioc.Locatable;
+import org.apache.tapestry5.ioc.Locatable;
 import org.slf4j.Logger;
 
 import java.util.Locale;
 
 /**
  * Operations shared by the public {@link org.apache.tapestry.ComponentResources} interface and {@link
  * org.apache.tapestry.internal.structure.ComponentPageElement} interface (on the internal side).
  */
 public interface ComponentResourcesCommon extends Locatable
 {
@@ -45,14 +45,14 @@
      * <p/>
      * This value is often used to obtain an equivalent component instance in a later request.
      *
-     * @see org.apache.tapestry.services.ComponentSource#getComponent(String)
+     * @see org.apache.tapestry5.services.ComponentSource#getComponent(String)
      */
 
     String getCompleteId();
 
     /**
      * A convienience for invoking {@link #triggerContextEvent(String, EventContext , ComponentEventCallback)}. Wraps
      * the context values into an {@link org.apache.tapestry.EventContext}.
      *
      * @param eventType event type (as determined from the request, or otherwise by design)
      * @param context   Values that may be provided to the event handler method as method parameters, or null if no
@@ -61,10 +61,10 @@
      *                  support return values from event handler methods (the value true is allowed even if the handler
      *                  is null).
      * @return true if any event handler was invoked (even if no event handler method returns a non-null value)
-     * @throws org.apache.tapestry.runtime.ComponentEventException
+     * @throws org.apache.tapestry5.runtime.ComponentEventException
      *          if an event handler method throws a checked or unchecked exception
-     * @see org.apache.tapestry.internal.transform.OnEventWorker
-     * @see org.apache.tapestry.annotation.OnEvent
+     * @see org.apache.tapestry5.internal.transform.OnEventWorker
+     * @see org.apache.tapestry5.annotations.OnEvent
      */
     boolean triggerEvent(String eventType, Object[] contextValues, ComponentEventCallback callback);
 
@@ -83,10 +83,10 @@
      *                  support return values from event handler methods (the value true is allowed even if the handler
      *                  is null).
      * @return true if any event handler was invoked (even if no event handler method returns a non-null value)
-     * @throws org.apache.tapestry.runtime.ComponentEventException
+     * @throws org.apache.tapestry5.runtime.ComponentEventException
      *          if an event handler method throws a checked or unchecked exception
-     * @see org.apache.tapestry.internal.transform.OnEventWorker
-     * @see org.apache.tapestry.annotation.OnEvent
+     * @see org.apache.tapestry5.internal.transform.OnEventWorker
+     * @see org.apache.tapestry5.annotations.OnEvent
      */
     boolean triggerContextEvent(String eventType, EventContext context, ComponentEventCallback callback);
 
@@ -99,7 +99,7 @@
     /**
      * Returns the log instance associated with the component (which is based on the component or mixin's class name).
      *
-     * @see org.apache.tapestry.model.ComponentModel#getLogger()
+     * @see org.apache.tapestry5.model.ComponentModel#getLogger()
      */
     Logger getLogger();
 
@@ -12,16 +12,16 @@
 
 /**
- * Operations shared by the public {@link org.apache.tapestry.ComponentResources} interface and {@link
- * org.apache.tapestry.internal.structure.ComponentPageElement} interface (on the internal side).
+ * Operations shared by the public {@link org.apache.tapestry5.ComponentResources} interface and {@link
+ * org.apache.tapestry5.internal.structure.ComponentPageElement} interface (on the internal side).
  */
 public interface ComponentResourcesCommon extends Locatable
@@ -45,14 +45,14 @@
     /**
      * A convienience for invoking {@link #triggerContextEvent(String, EventContext , ComponentEventCallback)}. Wraps
-     * the context values into an {@link org.apache.tapestry.EventContext}.
+     * the context values into an {@link org.apache.tapestry5.EventContext}.
      *
      * @param eventType event type (as determined from the request, or otherwise by design)

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/ContentType.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/ContentType.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/Field.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/Field.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry;
+package org.apache.tapestry5;
 
 /**
  * Defines a field within a form.  Fields have a <a href="http://www.w3.org/TR/html4/interact/forms.html#control-name">control
@@ -20,7 +20,7 @@
  * <p/>
  * Timing is important, as components may render multiple times, due to looping and other factors. Generally, a
  * component's {@link #getControlName()} will only be accurate after it has rendered.  In some cases, when generating
  * JavaScript for example, it is necessary to {@linkplain org.apache.tapestry.services.Heartbeat#defer(Runnable) wait
  * until the end of the current Heartbeat} to ensure that all components have had thier chance to render.
  */
 public interface Field extends ClientElement
@@ -29,7 +29,7 @@
      * Returns the value used as the name attribute of the rendered element. This value will be unique within an
      * enclosing form, even if the same component renders multiple times.
      *
-     * @see org.apache.tapestry.services.FormSupport#allocateControlName(String)
+     * @see org.apache.tapestry5.services.FormSupport#allocateControlName(String)
      */
     String getControlName();
 
@@ -38,7 +38,7 @@
      * the client, and inside client or server-side validation error messages.
      *
      * @return the label
-     * @see org.apache.tapestry.corelib.components.Label
+     * @see org.apache.tapestry5.corelib.components.Label
      */
     String getLabel();
 
@@ -52,7 +52,7 @@
     boolean isDisabled();
 
     /**
      * Returns true if this field required (as per {@link org.apache.tapestry.FieldValidator#isRequired()}).
      *
      * @return true if a non-blank value is required for the field
      */
@@ -20,7 +20,7 @@
  * Timing is important, as components may render multiple times, due to looping and other factors. Generally, a
  * component's {@link #getControlName()} will only be accurate after it has rendered.  In some cases, when generating
- * JavaScript for example, it is necessary to {@linkplain org.apache.tapestry.services.Heartbeat#defer(Runnable) wait
+ * JavaScript for example, it is necessary to {@linkplain org.apache.tapestry5.services.Heartbeat#defer(Runnable) wait
  * until the end of the current Heartbeat} to ensure that all components have had thier chance to render.
  */
@@ -52,7 +52,7 @@
 
     /**
-     * Returns true if this field required (as per {@link org.apache.tapestry.FieldValidator#isRequired()}).
+     * Returns true if this field required (as per {@link org.apache.tapestry5.FieldValidator#isRequired()}).
      *
      * @return true if a non-blank value is required for the field

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/FieldValidationSupport.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/FieldValidationSupport.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/FieldValidationSupport.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/FieldValidationSupport.java Tue May 20 11:51:35 2008
@@ -12,17 +12,17 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry;
+package org.apache.tapestry5;
 
 /**
  * Services to help with field {@linkplain org.apache.tapestry.Validator validation} and {@linkplain
  * org.apache.tapestry.Translator translation}. This service encapsulates the logic that mixes normal
  * configured/declared validation/translation with events triggered on the component.
  */
 public interface FieldValidationSupport
 {
     /**
      * A wrapper around {@link org.apache.tapestry.Translator#toClient(Object)} that first fires a "toclient" event on
      * the component to see if it can perform the conversion. If the value is null, then no event is fired and the
      * translator is <em>not</em> invoked, the return value is simply null.
      *
@@ -31,13 +31,13 @@
      * @param translator         used if the component does not provide a non-null value
      * @param nullFieldStrategy  used to convert a null server side value to an appropriate client side value
      * @return the translated value  or null if the value is null
-     * @see org.apache.tapestry.Translator#toClient(Object)
+     * @see org.apache.tapestry5.Translator#toClient(Object)
      */
     String toClient(Object value, ComponentResources componentResources, Translator translator,
                     NullFieldStrategy nullFieldStrategy);
 
     /**
      * A wrapper around {@link org.apache.tapestry.Translator#parseClient(String, org.apache.tapestry.ioc.Messages)}.
      * First a "parseclient" event is fired; the translator is only invoked if that returns null (typically because
      * there is not handler for the event).
      *
@@ -46,9 +46,9 @@
      * @param translator         translator that will do the work if the component event returns null
      * @param nullFieldStrategy  used to convert null/blank values from client into non-null server side values
      * @return the input parsed to an object
-     * @throws org.apache.tapestry.ValidationException
+     * @throws org.apache.tapestry5.ValidationException
      *          if the value can't be parsed
-     * @see org.apache.tapestry.Translator#parseClient(String, org.apache.tapestry.ioc.Messages)
+     * @see org.apache.tapestry5.Translator#parseClient(String, org.apache.tapestry5.ioc.Messages)
      */
     Object parseClient(String clientValue, ComponentResources componentResources, Translator translator,
                        NullFieldStrategy nullFieldStrategy)
@@ -62,8 +62,8 @@
      * @param componentResources used to trigger events
      * @param validator          performs normal validations
      * @throws ValidationException if the value is not valid
      * @see org.apache.tapestry.Validator#validate(Field, Object, org.apache.tapestry.ioc.MessageFormatter, Object)
      */
     void validate(Object value, ComponentResources componentResources, FieldValidator validator)
             throws ValidationException;
-}
\ No newline at end of file
+}
@@ -12,17 +12,17 @@
 
 /**
- * Services to help with field {@linkplain org.apache.tapestry.Validator validation} and {@linkplain
- * org.apache.tapestry.Translator translation}. This service encapsulates the logic that mixes normal
+ * Services to help with field {@linkplain org.apache.tapestry5.Validator validation} and {@linkplain
+ * org.apache.tapestry5.Translator translation}. This service encapsulates the logic that mixes normal
  * configured/declared validation/translation with events triggered on the component.
  */
@@ -12,17 +12,17 @@
 {
     /**
-     * A wrapper around {@link org.apache.tapestry.Translator#toClient(Object)} that first fires a "toclient" event on
+     * A wrapper around {@link org.apache.tapestry5.Translator#toClient(Object)} that first fires a "toclient" event on
      * the component to see if it can perform the conversion. If the value is null, then no event is fired and the
      * translator is <em>not</em> invoked, the return value is simply null.
@@ -31,13 +31,13 @@
 
     /**
-     * A wrapper around {@link org.apache.tapestry.Translator#parseClient(String, org.apache.tapestry.ioc.Messages)}.
+     * A wrapper around {@link org.apache.tapestry5.Translator#parseClient(String, org.apache.tapestry5.ioc.Messages)}.
      * First a "parseclient" event is fired; the translator is only invoked if that returns null (typically because
      * there is not handler for the event).
@@ -62,8 +62,8 @@
      * @param validator          performs normal validations
      * @throws ValidationException if the value is not valid
-     * @see org.apache.tapestry.Validator#validate(Field, Object, org.apache.tapestry.ioc.MessageFormatter, Object)
+     * @see org.apache.tapestry5.Validator#validate(Field, Object, org.apache.tapestry5.ioc.MessageFormatter, Object)
      */
     void validate(Object value, ComponentResources componentResources, FieldValidator validator)

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/FieldValidator.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/FieldValidator.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/FieldValidator.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/FieldValidator.java Tue May 20 11:51:35 2008
@@ -12,14 +12,14 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry;
+package org.apache.tapestry5;
 
 /**
  * Responsible for validation of a single field.
  *
  * @param <T>
  * @see Validator
- * @see org.apache.tapestry.services.FieldValidatorDefaultSource
+ * @see org.apache.tapestry5.services.FieldValidatorDefaultSource
  */
 public interface FieldValidator<T>
 {
@@ -34,19 +34,19 @@
     void validate(T value) throws ValidationException;
 
     /**
      * Invokes {@link Validator#render(Field, Object, org.apache.tapestry.ioc.MessageFormatter, MarkupWriter,
      * org.apache.tapestry.services.FormSupport)}. This is called at a point "inside" the tag, so that additional
      * attributes may be added.  In many cases, the underlying {@link org.apache.tapestry.Validator} may write
      * client-side JavaScript to enforce the constraint as well.
      *
      * @param writer markup writer to direct output to.
-     * @see org.apache.tapestry.MarkupWriter#attributes(Object[])
+     * @see org.apache.tapestry5.MarkupWriter#attributes(Object[])
      */
     void render(MarkupWriter writer);
 
     /**
      * Returns true if any underlying {@link org.apache.tapestry.Validator} returns true from {@link
      * org.apache.tapestry.Validator#isRequired()}.
      *
      * @return true if the field is required   (a non-blank value is expected)
      */
@@ -34,19 +34,19 @@
 
     /**
-     * Invokes {@link Validator#render(Field, Object, org.apache.tapestry.ioc.MessageFormatter, MarkupWriter,
-     * org.apache.tapestry.services.FormSupport)}. This is called at a point "inside" the tag, so that additional
-     * attributes may be added.  In many cases, the underlying {@link org.apache.tapestry.Validator} may write
+     * Invokes {@link Validator#render(Field, Object, org.apache.tapestry5.ioc.MessageFormatter, MarkupWriter,
+     * org.apache.tapestry5.services.FormSupport)}. This is called at a point "inside" the tag, so that additional
+     * attributes may be added.  In many cases, the underlying {@link org.apache.tapestry5.Validator} may write
      * client-side JavaScript to enforce the constraint as well.
      *
@@ -34,19 +34,19 @@
 
     /**
-     * Returns true if any underlying {@link org.apache.tapestry.Validator} returns true from {@link
-     * org.apache.tapestry.Validator#isRequired()}.
+     * Returns true if any underlying {@link org.apache.tapestry5.Validator} returns true from {@link
+     * org.apache.tapestry5.Validator#isRequired()}.
      *
      * @return true if the field is required   (a non-blank value is expected)

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/FormValidationControl.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/FormValidationControl.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/MarkupWriterAdapter.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/MarkupWriterAdapter.java Tue May 20 11:51:35 2008
@@ -12,12 +12,12 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry;
+package org.apache.tapestry5;
 
-import org.apache.tapestry.dom.Element;
+import org.apache.tapestry5.dom.Element;
 
 /**
  * Default, empty implementation of {@link org.apache.tapestry.MarkupWriterListener}.
  */
 public class MarkupWriterAdapter implements MarkupWriterListener
 {
@@ -12,12 +12,12 @@
 
 /**
- * Default, empty implementation of {@link org.apache.tapestry.MarkupWriterListener}.
+ * Default, empty implementation of {@link org.apache.tapestry5.MarkupWriterListener}.
  */
 public class MarkupWriterAdapter implements MarkupWriterListener

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/MarkupWriterListener.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/MarkupWriterListener.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/NullFieldStrategy.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/NullFieldStrategy.java Tue May 20 11:51:35 2008
@@ -12,27 +12,27 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry;
+package org.apache.tapestry5;
 
 /**
  * Defines a strategy, used by {@link Field} components such as {@link org.apache.tapestry.corelib.components.TextField},
  * to handle the case where either the server-side value to be sent (as a string) to the client, or the client-side
  * string passed back up to the server, is null or blank.
  *
- * @see org.apache.tapestry.services.NullFieldStrategySource
+ * @see org.apache.tapestry5.services.NullFieldStrategySource
  */
 public interface NullFieldStrategy
 {
     /**
      * Provides a replacement value for null, when converting the server-side object to a client-side string. The
      * replacement value, if non-null, will be passed to {@link org.apache.tapestry.Translator#toClient(Object)}.
      */
     Object replaceToClient();
 
     /**
      * Provides a replacement value for a null or blank string passed from the client to the server as part of a form
      * submission. This replacement value will be passed to {@link org.apache.tapestry.Translator#parseClient(String,
      * org.apache.tapestry.ioc.Messages)}  as if it were the value supplied by the user.
      *
      * @return replacement value (this must not be null)
      */
@@ -12,27 +12,27 @@
 
 /**
- * Defines a strategy, used by {@link Field} components such as {@link org.apache.tapestry.corelib.components.TextField},
+ * Defines a strategy, used by {@link Field} components such as {@link org.apache.tapestry5.corelib.components.TextField},
  * to handle the case where either the server-side value to be sent (as a string) to the client, or the client-side
  * string passed back up to the server, is null or blank.
@@ -12,27 +12,27 @@
     /**
      * Provides a replacement value for null, when converting the server-side object to a client-side string. The
-     * replacement value, if non-null, will be passed to {@link org.apache.tapestry.Translator#toClient(Object)}.
+     * replacement value, if non-null, will be passed to {@link org.apache.tapestry5.Translator#toClient(Object)}.
      */
     Object replaceToClient();
@@ -12,27 +12,27 @@
     /**
      * Provides a replacement value for a null or blank string passed from the client to the server as part of a form
-     * submission. This replacement value will be passed to {@link org.apache.tapestry.Translator#parseClient(String,
-     * org.apache.tapestry.ioc.Messages)}  as if it were the value supplied by the user.
+     * submission. This replacement value will be passed to {@link org.apache.tapestry5.Translator#parseClient(String,
+     * org.apache.tapestry5.ioc.Messages)}  as if it were the value supplied by the user.
      *
      * @return replacement value (this must not be null)

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/OptionGroupModel.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/OptionGroupModel.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================